<?php
/**
 * spd2014 functions and definitions
 *
 * @package spd2014
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 750; /* pixels */

if ( ! function_exists( 'spd2014_setup' ) ) :
/**
 * Set up theme defaults and register support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function spd2014_setup() {
    global $cap, $content_width;

    // This theme styles the visual editor with editor-style.css to match the theme style.
    add_editor_style();
    add_editor_style( get_template_directory_uri() . '/includes/resources/bootstrap/css/bootstrap.min.css' );

    if ( function_exists( 'add_theme_support' ) ) {

		/**
		 * Add default posts and comments RSS feed links to head
		*/
		add_theme_support( 'automatic-feed-links' );
		
		/**
		 * Enable support for Post Thumbnails on posts and pages
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		*/
		add_theme_support( 'post-thumbnails' );
		
		/**
		 * Enable support for Post Formats
		*/
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
		
		/**
		 * Header customization
		*/
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
		add_theme_support( 'custom-header-image', apply_filters( 'spd2014_custom_header_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );
	
    }

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on spd2014, use a find and replace
	 * to change 'spd2014' to the name of your theme in all the template files
	*/
	load_theme_textdomain( 'spd2014', get_template_directory() . '/languages' );

	add_image_size( 'Portrait-(150px)', 150, 9999, false );
	add_image_size( 'Portrait-(300px)', 300, 9999, false );
        add_image_size( 'Landschaft-(150px)', 9999, 150, false );
        add_image_size( 'Landschaft-(300px)', 9999, 300, false );


	/**
	 * This theme uses wp_nav_menu() in one location.
	*/ 
    register_nav_menus( array(
        'primary'  => __( 'Hauptmenü', 'spd2014' ),
        'meta'  => __( 'Metadaten', 'spd2014' ),
    ) );

}
endif; // spd2014_setup
add_action( 'after_setup_theme', 'spd2014_setup' );



/**
 * Register widgetized area and update sidebar with default widgets
 */
function spd2014_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'spd2014' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar(array(
		'name' => __( 'Footer Links', 'spd2014' ),
		'id' => 'footer-1',
		'before_widget' => '',
		'after_widget' => '',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));
	register_sidebar(array(
		'name' => __( 'Footer Mitte', 'spd2014' ),
		'id' => 'footer-2',
		'before_widget' => '',
		'after_widget' => '',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	));


}
add_action( 'widgets_init', 'spd2014_widgets_init' );


/**
 * This adds font awesome glyphicons to known widget titles
 */
function fancy_title($title) {
	$icon="";
	$title = __($title,'spd2014');
	switch (strtolower($title)) {
	case "letzte beiträge": 
		$icon = "info-circle";
		break;
	case "letzte kommentare":
		$icon = "comment";
		break;
	case "archiv":
	case "archive":
		$icon = "archive";
		break;
	case "categories":
	case "kategorien":
		$icon = "book";
		break;
	case "schlagwörter":
		$icon = "tags";
		break;
	case "meta":
	case "metadaten":
		$icon = "cogs";
		break;
	case "anstehende veranstaltungen":
	case "veranstaltungen":
	case "termine":
		$icon = "calendar";
		break;
	case "twitter":
		$icon = "twitter";
		break;
	case "facebook":
		$icon = "facebook";
		break;
	case "social":
		$icon = "group";
		break;
	}
	if ($icon) {
		$title = '<i class="fa fa-'.$icon.'"></i> '.$title;
	}
 return $title;
}
add_filter('widget_title', fancy_title);


/**
 * Improves display of images with descriptions and frames
 */

function my_post_image_html( $html, $post_id, $post_image_id, $size, $attr ) {
  $thumbnail_image = get_posts(array('p' => $post_image_id, 'post_type' => 'attachment'));
  if ($thumbnail_image && isset($thumbnail_image[0])) {

    $title = $thumbnail_image[0]->post_excerpt;
    // $src = wp_get_attachment_image_src(get_post_thumbnail_id(), $size);
    $fullsrc = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
    //$alt = get_the_title($id);

    //$html = '<img src="' .$src[0]. '" alt="' .$alt. '" class="' .$attr['class']. '" rel="' .$attr['rel']. '" />';

    if ($attr['lightbox'] == 'true') {
      $html = '<a rel="lightbox" href="' .$fullsrc[0]. '">' .$html. '</a>';
    } else {
      $html = '<a href="' .get_permalink( $post_id ). '">' .$html. '</a>';
    }
    if ($title) {
      $html = $html.'<div class="wp-caption-text">'.$title.'</div>';
    }

  }  

  $html = '<div class="wp-caption pull-left '. $attr['containerclass']. '">'.$html.'</div>';

  return $html;

}
add_filter( 'post_thumbnail_html', 'my_post_image_html',10,5);



/**
 * Adds extra image sizes for usage
 */
function display_custom_image_sizes( $sizes ) {
  global $_wp_additional_image_sizes;
  if ( empty($_wp_additional_image_sizes) ) 
    return $sizes;

  foreach ( $_wp_additional_image_sizes as $id => $data ) {
    if ( !isset($sizes[$id]) )
      $sizes[$id] = ucfirst( str_replace( '-', ' ', $id ) );
  }

  return $sizes;
}
add_filter( 'image_size_names_choose', 'display_custom_image_sizes' );

/**
 * Maximizes thumbnail quality during resize
 */
function jpeg_quality_callback($arg)
{
return 100;
}
add_filter('jpeg_quality', 'jpeg_quality_callback');

/**
 * Instead of style.css we like to load the style.min.css - keep it sync!
 */

function child_stylesheet_uri($stylesheet_uri, $stylesheet_dir_uri) {
  $stylesheet_uri = $stylesheet_dir_uri . '/style.min.css';
  return $stylesheet_uri . '?v=' . filemtime( get_stylesheet_directory() . '/style.css');
}
add_filter( 'stylesheet_uri', 'child_stylesheet_uri', 10, 2 );


/**
 * Enqueue scripts and styles
 */
function spd2014_scripts() {

    // load bootstrap css
    wp_enqueue_style( 'spd2014-bootstrap', get_template_directory_uri() . '/includes/resources/bootstrap/css/bootstrap.min.css' );

    // load spd2014 styles
    wp_enqueue_style( 'spd2014-style', get_stylesheet_uri() );

    // load bootstrap js
    wp_enqueue_script('spd2014-bootstrapjs', get_template_directory_uri().'/includes/resources/bootstrap/js/bootstrap.js', array('jquery') );

    // load bootstrap wp js
    wp_enqueue_script( 'spd2014-bootstrapwp', get_template_directory_uri() . '/includes/js/bootstrap-wp.js', array('jquery') );

    // equal heigths, solving it by css only runs into display bugs using anchor links
    wp_enqueue_script( 'spd2014-equalheights', get_template_directory_uri() . '/includes/js/jquery.equal-heights.js', array('jquery') );

    // load font awesome css
    wp_enqueue_style( 'spd2014-fontawesome', get_template_directory_uri() . '/includes/resources/font-awesome/css/font-awesome.min.css' );

    wp_enqueue_script( 'spd2014-skip-link-focus-fix', get_template_directory_uri() . '/includes/js/skip-link-focus-fix.js', array(), '20130115', true );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }

    if ( is_singular() && wp_attachment_is_image() ) {
        wp_enqueue_script( 'spd2014-keyboard-image-navigation', get_template_directory_uri() . '/includes/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
    }

}
add_action( 'wp_enqueue_scripts', 'spd2014_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/includes/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/includes/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/includes/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/includes/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/includes/jetpack.php';

/**
 * Load custom WordPress nav walker.
 */
require get_template_directory() . '/includes/bootstrap-wp-navwalker.php';

/**
 * Load custom Widgets.
 */
require get_template_directory() . '/widgets/become-member.php';
require get_template_directory() . '/widgets/imaged-link.php';


