<?php
/**
 * spd2014 Theme Customizer
 *
 * @package spd2014
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function spd2014_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

      $wp_customize->add_section( 'spd2014_options', 
         array(
            'title' => __( 'Themenanpassung', 'spd2014' ), //Visible title of section
            'priority' => 35, //Determines what order this appears in
            'capability' => 'edit_theme_options', //Capability needed to tweak
            'description' => __('Anpassungen für das SPD 2014 Design.', 'spd2014'), //Descriptive tooltip
         ) 
      );

      $wp_customize->add_setting( 'spd2014_options_logo',
         array(
            'type' => 'theme_mod', //Is this an 'option' or a 'theme_mod'?
            'default' => get_template_directory_uri() . '/images/default-logo.png',
            'capability' => 'edit_theme_options', //Optional. Special permissions for accessing this setting.
            'transport' => 'refresh', //What triggers a refresh of the setting? 'refresh' or 'postMessage' (instant)?
         ) 
      );      
      $wp_customize->add_setting( 'spd2014_options_logo_justify',
         array(
            'type' => 'theme_mod',
            'default' => 'logo-right',
            'capability' => 'edit_theme_options',
            'transport' => 'refresh', 
         ) 
      );      

      $wp_customize->add_control( new WP_Customize_Image_Control( 
         $wp_customize, 
         'spd2014_logo', 
         array(
            'label' => __( 'Verbandslogo (160 x 160)', 'spd2014' ), 
            'section' => 'spd2014_options', 
            'settings' => 'spd2014_options_logo'
         )
      ) );

      $wp_customize->add_control( 'spd2014_options_logo_justify', array(
      'label'   => 'Ausrichtung des Logos',
      'section' => 'spd2014_options',
      'type'    => 'select',
      'choices'    => array(
          'logo-right' => 'Rechtsbündig',
          'logo-center' => 'Zentriert'
          ),
      ) );


}
add_action( 'customize_register', 'spd2014_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function spd2014_customize_preview_js() {
	wp_enqueue_script( 'spd2014_customizer', get_template_directory_uri() . '/includes/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'spd2014_customize_preview_js' );
